==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nb.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Nothing shared with you yet" : "Ingenting er delt med deg enda",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "No compatible server found at {remote}" : "Ingen kompatibel tjener ble funnet på {remote}",
    "Invalid server URL" : "Ugyldig tjener adresse",
    "Failed to add the public link to your Nextcloud" : "Feil oppstod under oppretting av offentlig lenke til din Nextcloud",
    "Share" : "Del",
    "No expiration date set" : "Ingen utløpsdato er satt",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Downloaded by {email}" : "Lastet ned av {email}",
    "{file} downloaded via public link" : "{file} lastet ned via offentlig lenke",
    "{email} downloaded {file}" : "{email} lastet ned {file}",
    "Shared with group {group}" : "Delt med gruppen {group}",
    "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
    "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
    "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernet gruppen {group} fra {file}",
    "Shared as public link" : "Delt som offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "{actor} shared as public link" : "{actor} delte som offentlig lenke",
    "{actor} removed public link" : "{actor} fjernet offentlig lenke",
    "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
    "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
    "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
    "Public link expired for {file}" : "Offentlig lenke er utløprt for {file}",
    "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
    "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
    "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
    "{user} accepted the remote share" : "{user} godtok fjerndelingen",
    "{user} declined the remote share" : "{user} avslo fjerndelingen",
    "You received a new remote share {file} from {user}" : "Du har mottatt en ny fjerndeling {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} godtok fjerndelingen av {file}",
    "{user} declined the remote share of {file}" : "{user} avslo fjerndelingen av {file}",
    "{user} unshared {file} from you" : "{user} fjernet deling av {file} med deg",
    "Shared with {user}" : "Delt med {user}",
    "Removed share for {user}" : "Fjernet deling med {user}",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernet deling med {user}",
    "Shared by {actor}" : "Delt av {actor}",
    "{actor} removed share" : "{actor} fjernet deling",
    "You shared {file} with {user}" : "Du delte {file} med {user}",
    "You removed {user} from {file}" : "Du fjernet {user} fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delete {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernet {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med deg",
    "{actor} removed you from {file}" : "{actor} fjernet deg fra {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ei fil eller mappe delt via e-post eller offentlig lenke ble <strong>lastet ned</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen tjener</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "Wrong share ID, share doesn't exist" : "Feil ressurs ID, ressursen finnes ikke",
    "could not delete share" : "kunne ikke slette ressursen",
    "Could not delete share" : "Kunne ikke slette ressursen",
    "Please specify a file or folder path" : "Oppgi en fil eller mappesti",
    "Wrong path, file/folder doesn't exist" : "Feil filbane, filen/mappen finnes ikke",
    "Could not create share" : "Kunne ikke opprette ressurs",
    "invalid permissions" : "Ugyldige rettigheter",
    "Please specify a valid user" : "Oppgi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Oppgi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Administratoren har skrudd av offentlig lenkedeling",
    "Public upload disabled by the administrator" : "Offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig i offentlig delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deling av %s mislyktes på grunn av at tjeneren ikke tillater deling av filtypen %s",
    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele til en sirkel så lenge programmet ikke er aktivert",
    "Please specify a valid circle" : "Angi en gyldig sirkel",
    "Unknown share type" : "Ukjent ressurstype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Kunne ikke låse sti",
    "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlige lenker",
    "Cannot increase permissions" : "Kan ikke øke tillatelser",
    "%s is publicly shared" : "%s er delt offentlig",
    "Share API is disabled" : "Deling API er deaktivert",
    "File sharing" : "Fildeling",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Password" : "Passord",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "shared by %s" : "delt av %s",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "Download" : "Last ned",
    "Download %s" : "Last ned %s",
    "Direct link" : "Direkte lenke",
    "Upload files to %s" : "Last opp filer til %s",
    "Select or drop files" : "Velg eller slipp filer",
    "Uploading files…" : "Laster opp filer...",
    "Uploaded files:" : "Opplastede filer:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/nb.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med deg",
    "Shared by link" : "Delt med lenke",
    "Deleted shares" : "Slettede delinger",
    "Shares" : "Delinger",
    "Nothing shared with you yet" : "Ingenting er delt med deg enda",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you deleted will show up here" : "Delinger du har slettet vil vises her",
    "No shares" : "Ingen delinger",
    "Shares will show up here" : "Delinger vil vises her",
    "Restore share" : "Gjenopprett deling",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "Terms of service" : "Betingelser for tjenesten",
    "No compatible server found at {remote}" : "Ingen kompatibel server ble funnet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Feil oppstod under oppretting av offentlig lenke til din Nextcloud",
    "No expiration date set" : "Ingen utløpsdato er satt",
    "Shared by" : "Delt av",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Downloaded by {email}" : "Lastet ned av {email}",
    "{file} downloaded via public link" : "{file} lastet ned via offentlig lenke",
    "{email} downloaded {file}" : "{email} lastet ned {file}",
    "Shared with group {group}" : "Delt med gruppen {group}",
    "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
    "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
    "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernet gruppen {group} fra {file}",
    "Shared as public link" : "Delt som offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "{actor} shared as public link" : "{actor} delte som offentlig lenke",
    "{actor} removed public link" : "{actor} fjernet offentlig lenke",
    "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
    "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
    "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
    "Public link expired for {file}" : "Offentlig lenke er utløprt for {file}",
    "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
    "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
    "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
    "{user} accepted the remote share" : "{user} godtok fjerndelingen",
    "{user} declined the remote share" : "{user} avslo fjerndelingen",
    "You received a new remote share {file} from {user}" : "Du har mottatt en ny fjerndeling {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} godtok fjerndelingen av {file}",
    "{user} declined the remote share of {file}" : "{user} avslo fjerndelingen av {file}",
    "{user} unshared {file} from you" : "{user} opphevde deling av {file} med deg",
    "Shared with {user}" : "Delt med {user}",
    "Removed share for {user}" : "Fjernet deling med {user}",
    "You removed yourself" : "Du fjernet deg selv",
    "{actor} removed themselves" : "{actor} fjernet seg selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernet deling med {user}",
    "Shared by {actor}" : "Delt av {actor}",
    "{actor} removed share" : "{actor} fjernet deling",
    "You shared {file} with {user}" : "Du delte {file} med {user}",
    "You removed {user} from {file}" : "Du fjernet {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernet deg selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernet seg selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delete {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernet {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med deg",
    "{actor} removed you from the share named {file}" : "{actor} fjernet deg fra delingen kalt {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ei fil eller mappe delt via e-post eller offentlig lenke ble <strong>lastet ned</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "Wrong share ID, share doesn't exist" : "Feil ressurs ID, ressursen finnes ikke",
    "Could not delete share" : "Kunne ikke slette ressursen",
    "Please specify a file or folder path" : "Oppgi en fil eller mappesti",
    "Wrong path, file/folder doesn't exist" : "Feil filbane, filen/mappen finnes ikke",
    "Could not create share" : "Kunne ikke opprette ressurs",
    "invalid permissions" : "Ugyldige rettigheter",
    "Please specify a valid user" : "Oppgi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Oppgi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Administratoren har skrudd av offentlig lenkedeling",
    "Public upload disabled by the administrator" : "Offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig i offentlig delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele til en sirkel så lenge appen ikke er aktivert",
    "Please specify a valid circle" : "Angi en gyldig sirkel",
    "Unknown share type" : "Ukjent ressurstype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Kunne ikke låse sti",
    "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlige lenker",
    "shared by %s" : "delt av %s",
    "Download all files" : "Last ned alle filer",
    "Direct link" : "Direkte lenke",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "Share API is disabled" : "Deling API er deaktivert",
    "File sharing" : "Fildeling",
    "Sharing" : "Deling",
    "Share" : "Del",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "Share note" : "Delingsnotat",
    "Toggle grid view" : "Veksle rutenett-visning",
    "Download %s" : "Last ned %s",
    "Upload files to %s" : "Last opp filer til %s",
    "Note" : "Melding",
    "Select or drop files" : "Velg eller slipp filer",
    "Uploading files…" : "Laster opp filer…",
    "Uploaded files:" : "Opplastede filer:",
    "could not delete share" : "kunne ikke slette ressursen"
},
"nplurals=2; plural=(n != 1);");
